#payment_order_renderer

Библиотека для создания документов платежного поручения в формате pdf.
Под капотом содержит printpdf для rust.

TODO
1 Добавить тесты
2 Добавить больше обработок ошибок
3 добавить модуль, который будет писать сумму в прописном виде
